package com.example.pda.function

// 顶层数据类声明
data class ResultCount(
    val normalizedResult: String,
    val occurrences: Int
)

class ResultCounter {
    // 使用LinkedHashMap保持插入顺序（可选）
    private val resultMap = mutableMapOf<String, Int>()

    // 线程安全版本（如需多线程访问）：
    // private val resultMap = java.util.concurrent.ConcurrentHashMap<String, Int>()

    /**
     * 添加结果并进行标准化处理
     * @param rawResult 原始输入字符串
     */
    fun addResult(rawResult: String) {
        val normalized = normalizeResult(rawResult)
        resultMap[normalized] = resultMap.getOrDefault(normalized, 0) + 1
    }

    /**
     * 获取所有统计结果，默认按首次出现顺序返回
     * 可选排序方式（按字母序/出现次数）通过参数控制
     */
    fun getStatistics(sortBy: SortOrder = SortOrder.INSERTION): List<ResultCount> {
        return when (sortBy) {
            SortOrder.ALPHABETICAL -> resultMap.map { (k, v) ->
                ResultCount(k, v)
            }.sortedBy { it.normalizedResult }

            SortOrder.OCCURRENCE -> resultMap.map { (k, v) ->
                ResultCount(k, v)
            }.sortedByDescending { it.occurrences }

            SortOrder.INSERTION -> resultMap.map { (k, v) ->
                ResultCount(k, v)
            }
        }
    }


    private fun normalizeResult(input: String): String {
        return input
//            .replace(Regex("\\s"), "")  // 移除所有空白
//            .lowercase()
//            .toCharArray()
//            .sorted()
//            .joinToString(",")
    }

    // 可选：重置统计
    fun clear() {
        resultMap.clear()
    }

    // 排序选项枚举
    enum class SortOrder {
        INSERTION,   // 插入顺序
        ALPHABETICAL, // 字母顺序
        OCCURRENCE    // 出现次数
    }
}