package com.example.pda.function;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.device.ScanManager;
import android.device.scanner.configuration.PropertyID;
import android.os.Vibrator;

import androidx.core.content.ContextCompat;

public class UBXScan {

    public UBXScan(){
        initScan();
    }

    /**监听**/
    public void setOnScanListener(Context context, OnScanListener listener) {
        // 设置扫描监听器和上下文环境
        this.mOnScanListener = listener;
        this.mContext = context;

        // 创建一个意图过滤器
        IntentFilter filter = new IntentFilter();
        // 定义需要获取的参数ID数组
        int[] idbuf = new int[]{PropertyID.WEDGE_INTENT_ACTION_NAME, PropertyID.WEDGE_INTENT_DATA_STRING_TAG};
        // 获取参数值数组
        String[] value_buf = mScanManager.getParameterString(idbuf);
        // 检查参数值数组是否有效且第一个值不为空字符串
        if (value_buf != null && value_buf[0] != null && !value_buf[0].equals("")) {
            // 如果有效，将第一个参数值作为动作添加到过滤器中
            filter.addAction(value_buf[0]);
        } else {
            // 如果无效，使用默认的扫描动作
            filter.addAction(SCAN_ACTION);
        }
        // 注册扫描接收器
        ContextCompat.registerReceiver(mContext, mScanReceiver, filter, ContextCompat.RECEIVER_NOT_EXPORTED);
    }
    public interface OnScanListener{
        void getCode(String code);
    }
    /**销毁**/
    public void destroy(){
        if(mScanManager!=null) {
            mScanManager.stopDecode();
        }
        if(mScanReceiver!=null) {
            mContext.unregisterReceiver(mScanReceiver);
        }
    }

    private final static String SCAN_ACTION = ScanManager.ACTION_DECODE;//default action

    private ScanManager mScanManager;
    private Context mContext;
    private OnScanListener mOnScanListener;

    private BroadcastReceiver mScanReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            byte[] barcode = intent.getByteArrayExtra(ScanManager.DECODE_DATA_TAG);
            int barcodelen = intent.getIntExtra(ScanManager.BARCODE_LENGTH_TAG, 0);
            byte temp = intent.getByteExtra(ScanManager.BARCODE_TYPE_TAG, (byte) 0);
            android.util.Log.i("debug", "----codetype--" + temp);
            String barcodeStr = new String(barcode, 0, barcodelen);
//            mTvText.append(" length：" + barcodelen);
//            mTvText.append(" barcode：" + barcodeStr);
//            mTvText.append(" barcode：" + bytesToHexString(barcode));
//            mTvText.setText(barcodeStr);
            if(mOnScanListener!=null){
                mOnScanListener.getCode(barcodeStr);
            }
        }
    };

    private void initScan(){
        mScanManager = new ScanManager();
        mScanManager.openScanner();
        //此段代码若不加，扫描会无反应
        mScanManager.switchOutputMode(0);
    }


    private String bytesToHexString(byte[] src) {
        StringBuilder stringBuilder = new StringBuilder("");
        if (src == null || src.length <= 0){
            return null;
        }
        for (int i = 0; i < src.length; i++) {
            int v = src[i] & 0xFF;
            String hv = Integer.toHexString(v);
            if (hv.length() < 2) {
                stringBuilder.append(0);
            }
            stringBuilder.append(hv);
        }
        return stringBuilder.toString();
    }


}
