package com.example.pda.navigation

import androidx.navigation.NavController
import androidx.navigation.NavGraphBuilder
import androidx.navigation.NavType
import androidx.navigation.compose.composable
import androidx.navigation.navArgument
import androidx.navigation.navigation
import com.example.pda.ui.DetailsScreen
import com.example.pda.ui.MainScreen
import com.example.pda.ui.ScanScreen

// 定义应用程序的导航图
fun NavGraphBuilder.appNavGraph(navController: NavController) {
    // 创建一个导航图，起始目标为 "main"，路由为 "root"
    navigation(startDestination = "main", route = "root") {
        // 定义 "main" 路由，显示主屏幕
        composable("main") {
            MainScreen(
                onInventoryScan = { navController.navigate("scan") }, // 点击扫描按钮时导航到 "scan" 路由
                onShelfScan = { navController.navigate("scan") }, // 点击扫描按钮时导航到 "scan" 路由
            )
        }
        // 定义 "scan" 路由，显示扫描屏幕
        composable("scan") {
            ScanScreen(
                onBack = { navController.popBackStack() }, // 点击返回按钮时弹出当前栈顶
                onResult = { result -> 
                    navController.navigate("details/$result") // 导航到 "details" 路由，传递结果参数
                }
            )
        }
        // 定义 "details" 路由，显示详情屏幕，需要传递结果参数
        composable(
            route = "details/{result}",
            arguments = listOf(navArgument("result") { type = NavType.StringType }) // 定义参数类型为字符串
        ) { backStackEntry ->
            DetailsScreen(
                result = backStackEntry.arguments?.getString("result") ?: "", // 获取并传递结果参数
                onMainScreen = {navController.navigate("main")}, // 点击返回按钮时导航到 "main" 路由
                onShelfScan = { navController.navigate("scan") }, // 点击上架按钮时导航到 "scan" 路由
                onBack = { navController.popBackStack() } // 点击返回按钮时弹出当前栈顶
            )
        }
    }
}